<?php 
/*
　* @$Id
　* @
　* @Ver: 2.0
　* @Create: 2009-11-18 8:10
　* @Modify: 
　* @Author: CPWEB http://www.cpweb.net.cn
　* @Copyright (C) 2008 www.cpweb.net.cn. All Rights Reserved.
　* @License CPWEB is free software and use is subject to license terms
　*/
class ProductAction extends GlobalAction 
{
	function _initialize()
	{
		parent::_initialize();
		$this->cpweb_model='model';
		$this->cpweb_find['view']='View';
		$this->cpweb_find['page']='1';
		$this->cpweb_find['thumb']=true;
	}
	public function index()
	{
		$key=array(
			array('value'=>'Product.subject','name'=>L('CPWEB_READ_SUBJECT')),
		);
		$this->cpweb_category();
		$this->assign('key',$key);
		$this->cpweb_list();
		$this->assign('title','产品管理');
		$this->display();
	}

	public function add()
	{
		$this->cpweb_category();
		$this->assign('title','添加产品');
		$this->display();
	}
	public function edit()
	{
		$this->cpweb_read();
		$this->cpweb_category();
		$this->assign('title','编辑产品');
		$this->display();
	}
	public function submit(){
		$act=$_REQUEST['act'];
		$id=intval($_REQUEST['id']);
		if($act=='delete'&&!is_array($id)){//单个删除时才检测栏目的删除权限
			$S=M('Product')->find($id);
			if (!$id||!$S) $this->error(L('CPWEB_SELECT_NOT_EXIST'));//检测删除的内容是否存在
			if($S['attachment']){
				$this->cpweb_new_delete_attach($S);
				$this->cpweb_new_delete_attachthumb($S);
			}
		}
		$this->_subAction();
	}
	public function categorysubmit(){
		$this->_subAction('Category');
	}
}
?>